package at.gv.brz.bjujq.erv.samples.common;

import at.gv.justiz.erv.ervanschriftcodekopplungnachrichtextern.v3_0.AnschriftcodeKopplungDatenTyp;
import at.gv.justiz.erv.ervanschriftcodekopplungserviceextern.v3_0.*;
import at.gv.justiz.erv.ervwertebereichextern.v3_0.KopplungsStatus;
import org.mockito.invocation.InvocationOnMock;
import org.mockito.stubbing.Answer;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

/**
 * Simple ERV-Anschriftcode-Kopplung port mock builder.
 */
public class MockErvAnschriftcodeKopplungPortBuilder {

    private ERVAnschriftcodeKopplungPortType mock;

    public MockErvAnschriftcodeKopplungPortBuilder() {
        this.mock = mock(ERVAnschriftcodeKopplungPortType.class);
    }

    public ERVAnschriftcodeKopplungPortType build() {
        return mock;
    }

    public MockErvAnschriftcodeKopplungPortBuilder withGetKopplungDaten() {
        try {
            when(this.mock.getKopplungDaten(any(GetKopplungDatenRequest.class))).then(new Answer<GetKopplungDatenResponse>() {
                @Override
                public GetKopplungDatenResponse answer(InvocationOnMock invocation) throws Throwable {
                    GetKopplungDatenRequest request = (GetKopplungDatenRequest) invocation.getArgument(0);

                    SchemaUtil.printWithHeader("GetKopplung Request", request);

                    GetKopplungDatenResponse response = SchemaUtil.OF_ANK_SERVICE.createGetKopplungDatenResponse();

                    for (String anschriftcode : request.getAnschriftcode()) {
                        AnschriftcodeKopplungDatenTyp anschriftcodeKopplungDatenTyp = SchemaUtil.OF_ANK_NR.createAnschriftcodeKopplungDatenTyp();
                        anschriftcodeKopplungDatenTyp.setAnschriftcode(anschriftcode);
                        anschriftcodeKopplungDatenTyp.setKopplungAenderungZeitpunkt(SchemaUtil.createCurrentDateTime());
                        anschriftcodeKopplungDatenTyp.setKopplungStatus(KopplungsStatus.K);
                        response.getAnschriftcodeKopplungDaten().add(anschriftcodeKopplungDatenTyp);
                    }

                    SchemaUtil.printWithHeader("GetKopplung Respone", response);
                    return response;
                }
            });
        } catch (ERVAnschriftcodeKopplungServiceException_Exception e) {
            throw new RuntimeException(e);
        }

        return this;
    }

    public MockErvAnschriftcodeKopplungPortBuilder withKoppeln() {
        try {
            when(this.mock.koppeln(any(KoppelnRequest.class))).then(new Answer<KoppelnResponse>() {
                @Override
                public KoppelnResponse answer(InvocationOnMock invocation) throws Throwable {
                    KoppelnRequest request = (KoppelnRequest) invocation.getArgument(0);

                    SchemaUtil.printWithHeader("Koppeln Request", request);

                    KoppelnResponse response = SchemaUtil.OF_ANK_SERVICE.createKoppelnResponse();

                    SchemaUtil.printWithHeader("Koppeln Response", response);
                    return response;
                }
            });
        } catch (ERVAnschriftcodeKopplungServiceException_Exception e) {
            throw new RuntimeException(e);
        }

        return this;
    }

    public MockErvAnschriftcodeKopplungPortBuilder withEntkoppeln() {
        try {
            when(this.mock.entkoppeln(any(EntkoppelnRequest.class))).then(new Answer<EntkoppelnResponse>() {
                @Override
                public EntkoppelnResponse answer(InvocationOnMock invocation) throws Throwable {
                    EntkoppelnRequest request = (EntkoppelnRequest) invocation.getArgument(0);

                    SchemaUtil.printWithHeader("Entkoppeln Request", request);

                    EntkoppelnResponse response = SchemaUtil.OF_ANK_SERVICE.createEntkoppelnResponse();

                    SchemaUtil.printWithHeader("Entkoppeln Response", response);

                    return response;
                }
            });
        } catch (ERVAnschriftcodeKopplungServiceException_Exception e) {
            throw new RuntimeException(e);
        }

        return this;
    }
}
