package at.gv.brz.bjujq.erv.samples.nachricht_nachweis;

import at.gv.brz.bjujq.erv.samples.common.MockErvNachrichtPortBuilder;
import at.gv.brz.bjujq.erv.samples.common.SchemaUtil;
import at.gv.justiz.erv.ervnachrichtextern.v3_0.ERVNachrichtTyp;
import at.gv.justiz.erv.ervnachrichtextern.v3_0.StatusTyp;
import at.gv.justiz.erv.ervnachrichtserviceextern.v3_0.ERVException_Exception;
import at.gv.justiz.erv.ervnachrichtserviceextern.v3_0.ERVNachrichtPortType;
import at.gv.justiz.erv.ervnachrichtserviceextern.v3_0.NachrichtEinbringenRequest;
import at.gv.justiz.erv.ervnachrichtserviceextern.v3_0.NachrichtEinbringenResponse;

/**
 * Nachricht in den ERV einbringen.
 */
public class NachrichtEinbringen {


    public static void main(String[] args) throws ERVException_Exception {
        ERVNachrichtPortType ervNachrichtPortType = new MockErvNachrichtPortBuilder()
                .withNachrichtEinbringen()
                .build();

        // Request fuer die Einbringung vorbereiten
        // Die Nachricht soll mit dem Anschriftcode RXXXXXX an die Justizanwendung VJ geschickt werden
        NachrichtEinbringenRequest request = SchemaUtil.OF_SERVICE.createNachrichtEinbringenRequest();
        ERVNachrichtTyp ervNachricht = SchemaUtil.createErvNachrichtToJustizAT("RXXXXXX", "VJ");
        request.setERVNachricht(ervNachricht);

        // ERV-Aufruf
        NachrichtEinbringenResponse response = ervNachrichtPortType.nachrichtEinbringen(request);

        // Fehlercodes siehe ERV-Publikation
        if (response.getFehler() != null) {

        } else {
            StatusTyp status = response.getNachrichtstatus();

            /*
              Bei erfolgreicher Einbringung wird der Status im ersten Schritt auf HINTERLEGT gesetzt.
              Der Status HINTERLEGT im ERV bedeutet dass die Nachricht vom ERV angenommen wurde (Regeln positiv durchlaufen) und zur Abholung fuer den Empfaenger bereit steht.
              Nachdem der Empfaenger die Nachricht abgeholt hat wird der Status auf ZUGESTELLT gesetzt, ab diesem Zeitpunkt macht es Sinn den Nachweis fuer die entsprechende Nachricht
              abzuholen, daher wird folgende Vorgehensweise nach einer erfolgreichen Einbringung empfohlen:

              1) Mit Hilfe der Schnittstelle NachrichtStatus (siehe Klasse NachrichtStatus) auf den Status ZUGESTELLT pollen (Pollintervall sollte bei einigen Sekunden liegen, keine ms).
              2) Sobald der Status der eingebrachten Nachricht auf ZUGESTELLT ist, kann nach max.5min (gilt fuer JUSTIZ_AT) die Schnittstelle NachweisAbholen
                 (siehe Klasse NachweisAbholen) aufgerufen werden, wenn ein Nachweis erwartet wird bzw. angefordert wurde.

             */
        }
    }
}
